buildgraphs: buildgraphs

Description Usage Examples

View source: R/buildgraphs.R

Description

The package contains a function that takes a dataset, the variable indexes and the directory location as arguments and creates bar plots and pie charts for categorical variables and box plots and histograms for numerical variables.

Usage

1
useful to build graphs

Examples

1

DeepshikhaBLSharma/buildgraphs documentation built on Oct. 30, 2019, 5:19 p.m.