The package contains a function that takes a dataset, the variable indexes and the directory location as arguments and creates bar plots and pie charts for categorical variables and box plots and histograms for numerical variables.
1 | useful to build graphs
|
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.